@@ -6,6 +6,8 @@
 @ GitHub : https://github.com/ZeroSeeker
 @ Gitee : https://gitee.com/ZeroSeeker
 """
+import time
+
 import requests
 import hashlib
 import envx
@@ -100,6 +102,7 @@ def make_sign_request(
     )
     if sign_res['code'] == 0:
         data['sign'] = sign_res['data']
+        data['ts'] = int(time.time())
         if verify is False:
             urllib3.disable_warnings()
             response = requests.request(
